# AquaCrop-OS
> Python version of AquaCropOS


```python
#hide
```

This file will become your README and also the index of your documentation.

## Install

`pip install aquacrop`

## How to use

import aquacrop and run

# to do:

 - Adjust dz so that it covers whole root zone. [0.1]*12 is default. if max_root>1.2 then keep 0.1m to final layer until last layer =0.3 or max_root is inside the root zone. If not add 0.1 to the second last layer and so on. 
